@@ -1,53 +1,8 @@
-#' Renders a plot as a base64-encoded image
-#'
-#' @param device Graphics device function, such as [grDevices::png]
-#'   or [grDevices::pdf]
-#' @param mimeType Mime type for the data produced by `device`
-#' @param width Width of the plot in units applicable to `device`
-#' @param height Height of the plot in units applicable to `device`
-#' @param plotFn Function to call to perform the plot
-#' @seealso [encodePlotAsPng()]
-#' @seealso [encodePlotAsPdf()]
-encodePlot <- function(device, mimeType, width, height, plotFn) {
-    tempFilename <- tempfile(pattern='plot', fileext='png')
-    device(file=tempFilename, width=width, height=height)
-    tryCatch(plotFn(),finally=grDevices::graphics.off())
-    fileSize <- file.size(tempFilename)
-    raw <- readBin(tempFilename, what="raw", n=fileSize)
-    paste0("data:", mimeType, ";base64,", jsonlite::base64_enc(raw))
-}
-
-#' Renders a plot as a base64-encoded PNG
-#'
-#' The result can be set as the `src` attribute of an `img` element in HTML.
-#'
-#' @param width Width of the plot in pixels
-#' @param height Height of the plot in pixels
-#' @param plotFn Function to call to perform the plot
-#' @seealso [rrpcServer()]
-encodePlotAsPng <- function(width, height, plotFn) {
-    encodePlot(grDevices::png, "image/png", width, height, plotFn)
-}
-
-#' Renders a plot as a base64-encoded PDF
-#'
-#' The result can be set as the `href` attribute of an `a` element in HTML
-#' to allow the PDF to be downloaded (also set a `download` attribute to
-#' a reasonable filename).
-#'
-#' @param width Width of the plot in inches
-#' @param height Height of the plot in inches
-#' @param plotFn Function to call to perform the plot
-encodePlotAsPdf <- function(width, height, plotFn) {
-    encodePlot(grDevices::pdf, "application/pdf", width, height, plotFn)
-}
-
 selection2data <- function(input, method="U-Pb",format=1,ierr=1,d=IsoplotR::diseq(),
                            U8Th2=0,Th02i=c(0,0),Th02U48=c(0,0,1e6,0,0,0,0,0,0)){
-    nr <- as.numeric(input$nc)
     nc <- as.numeric(input$nc)
-    values <- matrix(as.character(input$data), ncol=nc)
-    mat <- matrix('',1,nc) # header
+    values <- matrix(as.character(input$data), ncol = nc)
+    mat <- matrix("", 1, nc) # header
     if (identical(method,"U-Pb") & format==1) {
         mat[1,1:5] <- c('Pb207U235','errPb207U235',
                         'Pb206U238','errPb206U238','rho')
@@ -254,105 +209,3 @@ selection2data <- function(input, method="U-Pb",format=1,ierr=1,d=IsoplotR::dise
     }
     out
 }
-
-# TODO: this should not just produce a plot in case of an error,
-# but run an error function supplied by the user because a plot
-# in not always sensible. A function to call on success would also
-# be useful.
-run <- function(Rcommand, input){
-
-    selection2levels <- function() {
-        nc <- as.numeric(input$nc)
-        values <- matrix(input$data, ncol=nc)
-        lc <- nc - 1
-        as.numeric(values[,lc])
-    }
-
-    selection2omit <- function() {
-        nc <- as.numeric(input$nc)
-        values <- matrix(input$data, ncol=nc)
-        oc <- nc
-        values[,oc]
-    }
-
-    omitter <- function(flags=c('x','X')) {
-        o <- selection2omit()
-        which(o%in%flags)
-    }
-
-    tryCatch({
-        eval(Rcommand)
-    }, error = function(e){
-        width <- 70
-        message1 <- e$message
-        message2 <- paste0("If this message does not make sense to you, then please save a ",
-                            "reproducible example as a .json file (using the 'Save' button ",
-                            "below) and email it to p.vermeesch@ucl.ac.uk. The problem will ",
-                            "be addressed asap.")
-        errormessage <- paste0("Error message:\n\n",wrap(message1,width),
-                                "\n\n",wrap(message2,width),"\n\n-PV")
-        print(e)
-        graphics::plot(c(0, 1),c(0,1),ann=F,bty ='n',type='n',xaxt='n',yaxt='n')
-        graphics::text(0.5,0,errormessage,cex=1.5,pos=3)
-    })
-
-}
-
-wrap <- function(tekst,width){
-    len <- nchar(tekst)
-    if (len <= width) {
-        return(tekst)
-    }
-    out <- tekst
-    spaces <- which(strsplit(tekst, "")[[1]]==" ")
-    toreplace <- seq(from=width,to=len,by=width)
-    for (i in 1:length(toreplace)){
-        j <- which.min(abs(spaces-toreplace[i]))
-        substr(out,spaces[j],spaces[j]) <- '\n'
-    }
-    out
-}
-
-server <-list()
-
-server$plotter <- function(width, height, Rcommand, input) {
-    forJson <- list()
-    forJson$action <- "plot"
-    forJson$width <- width
-    forJson$height <- height
-    forJson$src <- encodePlotAsPng(width, height, function() {
-        run(Rcommand, input)
-    })
-    forJson
-}
-
-server$runner <- function(Rcommand, input) {
-    forJson <- list()
-    forJson$action <- "results"
-    results <- run(Rcommand, input)
-    forJson$headers <- colnames(results)
-    forJson$data <- as.matrix(results)
-    forJson
-}
-
-server$getPdf <- function(Rcommand, input, fname) {
-    forJson <- list()
-    forJson$action <- "download"
-    forJson$filename <- fname
-    forJson$data <- encodePlotAsPdf(7, 7, function() {
-        run(Rcommand, input)
-    })
-    forJson
-}
-
-server$getCsv <- function(Rcommand, input, fname) {
-    forJson <- list()
-    forJson$action <- "download"
-    forJson$filename <- fname
-    results <- run(Rcommand, input);
-    raw <- utils::capture.output(utils::write.csv(results, stdout(), row.names=FALSE))
-    forJson$data <- paste0(
-        "data:text/csv;base64,",
-        jsonlite::base64_enc(raw))
-    forJson
-}
